Index: /issm/trunk/src/m/classes/public/mesh/rifts/meshprocessrifts.m
===================================================================
--- /issm/trunk/src/m/classes/public/mesh/rifts/meshprocessrifts.m	(revision 5649)
+++ /issm/trunk/src/m/classes/public/mesh/rifts/meshprocessrifts.m	(revision 5650)
@@ -7,8 +7,7 @@
 %
 %   Usage:
-%      md=meshprocessrifts(md)
+%      md=meshprocessrifts(md,domainoutline)
 %
 %   Ex: 
-%      md=meshprocessrifts(md);
 %      md=meshprocessrifts(md,'DomainOutline.exp');
 %
@@ -16,8 +15,10 @@
 %some checks on arguments: 
 if nargout~=1,
+	help meshprocessrifts
 	error('meshprocessrifts usage error:');
 end
 
 if nargin~=2,
+	help meshprocessrifts
 	error('meshprocessrifts usage error:');
 end
Index: /issm/trunk/src/m/utils/Meca/paterson.m
===================================================================
--- /issm/trunk/src/m/utils/Meca/paterson.m	(revision 5649)
+++ /issm/trunk/src/m/utils/Meca/paterson.m	(revision 5650)
@@ -3,9 +3,12 @@
 %
 %   rigidigty (in s^(1/3)Pa) is the flow law paramter in the flow law sigma=B*e(1/3) (Paterson, p97). 
 %   temperature is in Celsius degrees
 %
 %   Usage:
 %      rigidity=paterson(temperature)
 
+if(temperature<0)
+	error('input temperature should be in Kelvin (positive)');
+end
 T=temperature-273.15;
 
@@ -3,9 +3,12 @@
 %
 %   rigidigty (in s^(1/3)Pa) is the flow law paramter in the flow law sigma=B*e(1/3) (Paterson, p97). 
-%   temperature is in Celsius degrees
+%   temperature is in Kelvin degrees
 %
 %   Usage:
